@@ -31,9 +31,8 @@
 #' }  
 #'
 #' @importFrom rstan stan rstan_options extract
-#' @importFrom modeest mlv
 #' @importFrom mail sendmail
-#' @importFrom stats median qnorm
+#' @importFrom stats median qnorm density
 #' @importFrom utils read.table
 #'
 #' @details 
@@ -41,7 +40,7 @@
 #' 
 #' \strong{data} should be assigned a character value specifying the full path and name of the file, including the file extension 
 #' (e.g. ".txt"), that contains the behavioral data of all subjects of interest for the current analysis. 
-#' The file should be a text (.txt) file whose rows represent trial-by-trial observations and columns 
+#' The file should be a \strong{tab-delimited} text (.txt) file whose rows represent trial-by-trial observations and columns 
 #' represent variables. For the Go/No-Go Task, there should be four columns of data with the labels "subjID", 
 #' "cue", "keyPressed", and "outcome". It is not necessary for the columns to be in this particular order, 
 #' however it is necessary that they be labelled correctly and contain the information below:
@@ -124,12 +123,12 @@ gng_m1 <- function(data          = "choose",
   
   # Path to .stan model file
   if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
-    modelPath <- system.file("exec", "gng_m1_reg.stan", package="hBayesDM")
+    modelPath <- system.file("stan", "gng_m1_reg.stan", package="hBayesDM")
     cat("************************************\n")
     cat("** Extract model-based regressors **\n")
     cat("************************************\n")
   } else {
-    modelPath <- system.file("exec", "gng_m1.stan", package="hBayesDM")
+    modelPath <- system.file("stan", "gng_m1.stan", package="hBayesDM")
   }
   
   # To see how long computations take
@@ -245,7 +244,7 @@ gng_m1 <- function(data          = "choose",
   } else {
     genInitList <- "random"
   }
-  
+  rstan::rstan_options(auto_write = TRUE)
   if (ncore > 1) {
     numCores <- parallel::detectCores()
     if (numCores < ncore) {
@@ -258,25 +257,19 @@ gng_m1 <- function(data          = "choose",
     options(mc.cores = 1)
   }
   
-  
-  cat("***********************************\n")
-  cat("**  Loading a precompiled model  **\n")
-  cat("***********************************\n")
+  cat("************************************\n")
+  cat("** Building a model. Please wait. **\n")
+  cat("************************************\n")
   
   # Fit the Stan model
-  if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
-    m = stanmodels$gng_m1_reg
-  } else {
-    m = stanmodels$gng_m1
-  }
-  fit <- rstan::sampling(m,
-                     data    = dataList, 
-                     pars    = POI,
-                     warmup  = nwarmup,
-                     init    = genInitList, 
-                     iter    = niter, 
-                     chains  = nchain,
-                     thin    = nthin,
+  fit <- rstan::stan(file   = modelPath, 
+                     data   = dataList, 
+                     pars   = POI,
+                     warmup = nwarmup,
+                     init   = genInitList, 
+                     iter   = niter, 
+                     chains = nchain,
+                     thin   = nthin,
                      control = list(adapt_delta   = adapt_delta, 
                                     max_treedepth = max_treedepth, 
                                     stepsize      = stepsize) )
@@ -302,9 +295,9 @@ gng_m1 <- function(data          = "choose",
                             median(ep[, i]), 
                             median(rho[, i]) )
     } else if (indPars=="mode") {
-      allIndPars[i, ] <- c( as.numeric(modeest::mlv(xi[, i], method="shorth")[1]),
-                            as.numeric(modeest::mlv(ep[, i], method="shorth")[1]),
-                            as.numeric(modeest::mlv(rho[, i], method="shorth")[1]) )
+      allIndPars[i, ] <- c( estimate_mode(xi[, i]),
+                            estimate_mode(ep[, i]),
+                            estimate_mode(rho[, i]) )
     }
   }
   
@@ -327,10 +320,10 @@ gng_m1 <- function(data          = "choose",
       Wgo   = apply(parVals$Wgo, c(2,3), median)
       Wnogo = apply(parVals$Wnogo, c(2,3), median)
     } else if (indPars=="mode") {
-      Qgo   = apply(parVals$Qgo, c(2,3), modeest::mfv)   # using mfv function
-      Qnogo = apply(parVals$Qnogo, c(2,3), modeest::mfv) # using mfv function
-      Wgo   = apply(parVals$Wgo, c(2,3), modeest::mfv)   # using mfv function
-      Wnogo = apply(parVals$Wnogo, c(2,3), modeest::mfv) # using mfv function
+      Qgo   = apply(parVals$Qgo, c(2,3), estimate_mode)   # using mfv function
+      Qnogo = apply(parVals$Qnogo, c(2,3), estimate_mode) # using mfv function
+      Wgo   = apply(parVals$Wgo, c(2,3), estimate_mode)   # using mfv function
+      Wnogo = apply(parVals$Wnogo, c(2,3), estimate_mode) # using mfv function
     }
     # initialize modelRegressor and add model-based regressors
     modelRegressor = NULL
@@ -361,7 +354,8 @@ gng_m1 <- function(data          = "choose",
     currHr    <- substr(currTime, 12, 13)
     currMin   <- substr(currTime, 15, 16)
     timeStamp <- paste0(currDate, "_", currHr, "_", currMin)
-    save(modelData, file=file.path(saveDir, paste0(modelName, "_", timeStamp, ".RData"  ) ) )
+    dataFileName = sub(pattern = "(.*)\\..*$", replacement = "\\1", basename(data))
+    save(modelData, file=file.path(saveDir, paste0(modelName, "_", dataFileName, "_", timeStamp, ".RData"  ) ) )
   }
   
   # Send email to notify user of completion
