@@ -31,9 +31,8 @@
 #' }  
 #'
 #' @importFrom rstan stan rstan_options extract
-#' @importFrom modeest mlv
 #' @importFrom mail sendmail
-#' @importFrom stats median qnorm
+#' @importFrom stats median qnorm density
 #' @importFrom utils read.table
 #'
 #' @details 
@@ -41,7 +40,7 @@
 #' 
 #' \strong{data} should be assigned a character value specifying the full path and name of the file, including the file extension 
 #' (e.g. ".txt"), that contains the behavioral data of all subjects of interest for the current analysis. 
-#' The file should be a text (.txt) file whose rows represent trial-by-trial observations and columns 
+#' The file should be a \strong{tab-delimited} text (.txt) file whose rows represent trial-by-trial observations and columns 
 #' represent variables. For the Go/No-Go Task, there should be four columns of data with the labels "subjID", 
 #' "cue", "keyPressed", and "outcome". It is not necessary for the columns to be in this particular order, 
 #' however it is necessary that they be labelled correctly and contain the information below:
@@ -124,12 +123,12 @@ gng_m4 <- function(data          = "choose",
   
   # Path to .stan model file
   if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
-    modelPath <- system.file("exec", "gng_m4_reg.stan", package="hBayesDM")
+    modelPath <- system.file("stan", "gng_m4_reg.stan", package="hBayesDM")
     cat("************************************\n")
     cat("** Extract model-based regressors **\n")
     cat("************************************\n")
   } else {
-    modelPath <- system.file("exec", "gng_m4.stan", package="hBayesDM")
+    modelPath <- system.file("stan", "gng_m4.stan", package="hBayesDM")
   }
   
   # To see how long computations take
@@ -248,7 +247,7 @@ gng_m4 <- function(data          = "choose",
   } else {
     genInitList <- "random"
   }
-    
+  rstan::rstan_options(auto_write = TRUE)  
   if (ncore > 1) {
     numCores <- parallel::detectCores()
     if (numCores < ncore) {
@@ -261,17 +260,12 @@ gng_m4 <- function(data          = "choose",
     options(mc.cores = 1)
   }
   
-  cat("***********************************\n")
-  cat("**  Loading a precompiled model  **\n")
-  cat("***********************************\n")
+  cat("************************************\n")
+  cat("** Building a model. Please wait. **\n")
+  cat("************************************\n")
   
   # Fit the Stan model
-  if (modelRegressor) { # model regressors (for model-based neuroimaging, etc.)
-    m = stanmodels$gng_m4_reg
-  } else {
-    m = stanmodels$gng_m4
-  }
-  fit <- rstan::sampling(m, 
+  fit <- rstan::stan(file   = modelPath, 
                      data   = dataList, 
                      pars   = POI,
                      warmup = nwarmup,
@@ -313,12 +307,12 @@ gng_m4 <- function(data          = "choose",
                             median(rhoRew[, i]),
                             median(rhoPun[, i]) )
     } else if (indPars=="mode") {
-      allIndPars[i, ] <- c( as.numeric(modeest::mlv(xi[, i], method="shorth")[1]),
-                            as.numeric(modeest::mlv(ep[, i], method="shorth")[1]),
-                            as.numeric(modeest::mlv(b[, i], method="shorth")[1]),
-                            as.numeric(modeest::mlv(pi[, i], method="shorth")[1]),
-                            as.numeric(modeest::mlv(rhoRew[, i], method="shorth")[1]),
-                            as.numeric(modeest::mlv(rhoPun[, i], method="shorth")[1]) )
+      allIndPars[i, ] <- c( estimate_mode(xi[, i]),
+                            estimate_mode(ep[, i]),
+                            estimate_mode(b[, i]),
+                            estimate_mode(pi[, i]),
+                            estimate_mode(rhoRew[, i]),
+                            estimate_mode(rhoPun[, i]) )
     }
   }
   
@@ -346,11 +340,11 @@ gng_m4 <- function(data          = "choose",
       Wnogo = apply(parVals$Wnogo, c(2,3), median)
       SV    = apply(parVals$SV, c(2,3), median)
     } else if (indPars=="mode") {
-      Qgo   = apply(parVals$Qgo, c(2,3), modeest::mfv)   # using mfv function
-      Qnogo = apply(parVals$Qnogo, c(2,3), modeest::mfv) # using mfv function
-      Wgo   = apply(parVals$Wgo, c(2,3), modeest::mfv)   # using mfv function
-      Wnogo = apply(parVals$Wnogo, c(2,3), modeest::mfv) # using mfv function
-      SV    = apply(parVals$SV, c(2,3), modeest::mfv)    # using mfv function
+      Qgo   = apply(parVals$Qgo, c(2,3), estimate_mode)   # using mfv function
+      Qnogo = apply(parVals$Qnogo, c(2,3), estimate_mode) # using mfv function
+      Wgo   = apply(parVals$Wgo, c(2,3), estimate_mode)   # using mfv function
+      Wnogo = apply(parVals$Wnogo, c(2,3), estimate_mode) # using mfv function
+      SV    = apply(parVals$SV, c(2,3), estimate_mode)    # using mfv function
     }
     # initialize modelRegressor and add model-based regressors
     modelRegressor = NULL
@@ -382,7 +376,8 @@ gng_m4 <- function(data          = "choose",
     currHr    <- substr(currTime, 12, 13)
     currMin   <- substr(currTime, 15, 16)
     timeStamp <- paste0(currDate, "_", currHr, "_", currMin)
-    save(modelData, file=file.path(saveDir, paste0(modelName, "_", timeStamp, ".RData"  ) ) )
+    dataFileName = sub(pattern = "(.*)\\..*$", replacement = "\\1", basename(data))
+    save(modelData, file=file.path(saveDir, paste0(modelName, "_", dataFileName, "_", timeStamp, ".RData"  ) ) )
   }
   
   # Send email to notify user of completion
